<?php
/**
 * The template for displaying room reviews (comment).
 *
 * This template can be overridden by copying it to yourtheme/wp-hotel-booking/single-room-reviews.php.
 *
 * @author  ThimPress, leehld
 * @package WP-Hotel-Booking/Templates
 * @version 1.6
 */

/**
 * Prevent loading this file directly
 */
defined( 'ABSPATH' ) || exit();

global $hb_room, $hb_settings;
$rating = $hb_room->average_rating();
$rating = number_format($rating, 1);

/**
 * @var $hb_room WPHB_Room
 * @var $hb_settings WPHB_Settings
 */

if ( ! comments_open() ) {
	return;
} ?>

<div id="reviews">

	<div class="dt-sc-title with-before-after-shape alignleft">
    	<h2 class="dt-sc-main-heading"><?php esc_html_e('Ratings', 'ora'); ?></h2>
    </div>

	<?php if ( $hb_settings->get( 'enable_review_rating' ) && ( $count = $hb_room->get_review_count() ) ) { ?>
        <div class="hb-single-room-rating-wrapper">
            <div class="hb-room-rating-box">
                <div class="hb-room-average-rating-value"><?php echo esc_html($rating).' / 5'; ?></div>
                <div itemprop="reviewRating" itemscope itemtype="http://schema.org/Rating" class="star-rating"
                     title="<?php echo sprintf( esc_attr__( 'Rated %d out of 5', 'ora' ), $rating ) ?>">
                    <span style="width:<?php echo esc_attr(( $rating / 5 ) * 100); ?>%"></span>
                </div>
                <div class="hb-room-total-rating">(<?php echo esc_html($count).' '.esc_html__('Ratings', 'ora').', <span>'.esc_html__('Avg', 'ora').'</span> '.$rating.' out of 5)'; ?></div>
            </div>
            <div class="hb-room-ratings-breakup"><?php
				$a = dt_travel_room_individual_rating($hb_room->ID);
				$res = array_count_values($a); ?>
                <ul>
                    <li>
                        <span class="hb-room-ratings-label">5</span>
                        <div class="hb-room-ratings-percentage">
                            <span class="dark-green" style="width:<?php echo ( (array_key_exists('5', $res ) ? $res[5] : 0) / $count ) * 100; ?>%"></span>
                        </div>
                        <span><?php echo array_key_exists('5', $res ) ? $res[5] : 0; ?></span>
                    </li>
                    <li>
                        <span class="hb-room-ratings-label">4</span>
                        <div class="hb-room-ratings-percentage">
                            <span class="green" style="width:<?php echo ( (array_key_exists('4', $res ) ? $res[4] : 0) / $count ) * 100; ?>%"></span>
                        </div>
                        <span><?php echo array_key_exists('4', $res ) ? $res[4] : 0; ?></span>
                    </li>
                    <li>
                        <span class="hb-room-ratings-label">3</span>
                        <div class="hb-room-ratings-percentage">
                            <span class="light-green" style="width:<?php echo ( (array_key_exists('3', $res ) ? $res[3] : 0) / $count ) * 100; ?>%"></span>
                        </div>
                        <span><?php echo array_key_exists('3', $res ) ? $res[3] : 0; ?></span>
                    </li>
                    <li>
                        <span class="hb-room-ratings-label">2</span>
                        <div class="hb-room-ratings-percentage">
                            <span class="yellow" style="width:<?php echo ( (array_key_exists('2', $res ) ? $res[2] : 0) / $count ) * 100; ?>%"></span>
                        </div>
                        <span><?php echo array_key_exists('2', $res ) ? $res[2] : 0; ?></span>
                    </li>
                    <li>
                        <span class="hb-room-ratings-label">1</span>
                        <div class="hb-room-ratings-percentage">
                            <span class="red" style="width:<?php echo ( (array_key_exists('1', $res ) ? $res[1] : 0) / $count ) * 100; ?>%"></span>
                        </div>
                        <span><?php echo array_key_exists('1', $res ) ? $res[1] : 0; ?></span>
                    </li>
                </ul>
            </div>
        </div><?php
	} ?>

    <div id="comments">
        <div class="dt-sc-title with-before-after-shape alignleft">
            <h2 class="dt-sc-main-heading"><?php esc_html_e('Our Reviews', 'ora'); ?></h2>
        </div>

		<?php if ( have_comments() ) { ?>
            <ul class="commentlist">
				<?php wp_list_comments( apply_filters( 'hb_room_review_list_args', array( 'callback' => 'hb_comments' ) ) ); ?>
            </ul>

			<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) { ?>
                <nav class="hb-pagination">
					<?php paginate_comments_links( apply_filters( 'hb_comment_pagination_args', array(
						'prev_text' => '&larr;',
						'next_text' => '&rarr;',
						'type'      => 'list',
					) ) );
					?>
                </nav>
			<?php } ?>

		<?php } else { ?>
            <p class="hb-noreviews"><?php esc_html_e( 'There are no reviews yet.', 'ora' ); ?></p>
		<?php } ?>
    </div>

	<?php if ( hb_customer_booked_room( $hb_room->id ) ) { ?>

        <div id="review_form_wrapper">
            <div id="review_form">
				<?php
				$commenter    = wp_get_current_commenter();
				$comment_form = array(
					'title_reply'          => have_comments() ? esc_html__( 'Add a review', 'ora' ) : esc_html__( 'Be the first to review', 'ora' ) . ' &ldquo;' . get_the_title() . '&rdquo;',
					'title_reply_to'       => esc_html__( 'Leave a Reply to %s', 'ora' ),
					'comment_notes_before' => '',
					'comment_notes_after'  => '',
					'fields'               => array(
						'author' => '<p class="comment-form-author">' . '<label for="author">' . esc_html__( 'Name', 'ora' ) . ' <span class="required">*</span></label> ' .
						            '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" aria-required="true" /></p></div>',
						'email'  => '<p class="comment-form-email"><label for="email">' . esc_html__( 'Email', 'ora' ) . ' <span class="required">*</span></label> ' .
						            '<input id="email" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" aria-required="true" /></p></div>',
					),
					'label_submit'         => esc_html__( 'Submit', 'ora' ),
					'logged_in_as'         => '',
					'comment_field'        => ''
				);

				$comment_form['fields']['author'] .= '<div class="column dt-sc-one-half"><p class="comment-form-author-role">' . '<label for="author-role">' . esc_html__( 'Role', 'ora' ) . '</label> ' . '<input id="author-role" name="author-role" type="text" size="30" aria-required="true" /></p>';

				if ( $hb_settings->get( 'enable_review_rating' ) ) {
					$comment_form['comment_field'] = '<p class="comment-form-rating"><label for="rating">' . esc_html__( 'Your Rating', 'ora' ) . '</label>
                        </p><div class="hb-rating-input"></div>';
				}

				$comment_form['comment_field'] .= '<p class="comment-form-comment"><label for="comment">' . esc_html__( 'Your Review', 'ora' ) . '</label><textarea id="comment" name="comment" cols="45" rows="8" aria-required="true"></textarea></p>';

				$comment_form['comment_field'] .= '<div class="column dt-sc-one-half first"><p class="comment-form-title"><label for="comment-title">' . esc_html__( 'Review Title', 'ora' ) . ' <span class="required">*</span></label><input id="comment-title" name="comment-title" type="text" size="30" aria-required="true" /></p>';

				comment_form( apply_filters( 'hb_product_review_comment_form_args', $comment_form ) );
				?>
            </div>
        </div>

	<?php } else { ?>
        <p class="hb-verification-required"><?php esc_html_e( 'Only logged in customers who have purchased this product may leave a review.', 'ora' ); ?></p>
	<?php }; ?>

    <div class="clear"></div>
</div>