<?php
/**
 * The template for displaying single room page.
 *
 * This template can be overridden by copying it to yourtheme/wp-hotel-booking/single-room.php.
 *
 * @author  ThimPress, leehld
 * @package WP-Hotel-Booking/Templates
 * @version 1.6
 */

/**
 * Prevent loading this file directly
 */
defined( 'ABSPATH' ) || exit();

get_header();

$global_breadcrumb = cs_get_option( 'show-breadcrumb' );

$settings = get_post_meta($post->ID,'_custom_settings',TRUE);
$settings = is_array( $settings ) ?  array_filter( $settings )  : array();

$header_class = '';
if( !empty( $global_breadcrumb ) ) {
	if( isset( $settings['enable-sub-title'] ) && $settings['enable-sub-title'] ) {
		$header_class = isset( $settings['breadcrumb_position'] ) ? $settings['breadcrumb_position'] : '';
	}
}?>
<!-- ** Header Wrapper ** -->
<div id="header-wrapper" class="<?php echo esc_attr($header_class); ?>">

    <!-- **Header** -->
    <header id="header">

        <div class="container"><?php
            /**
             * ora_header hook.
             * 
             * @hooked ora_vc_header_template - 10
             *
             */
            do_action( 'ora_header' ); ?>
        </div>
    </header><!-- **Header - End ** -->

    <!-- ** Breadcrumb ** -->
    <?php
		# Global Breadcrumb
		if( !empty( $global_breadcrumb ) ) {

			if(empty($settings)) { $settings['enable-sub-title'] = true; }

			if( isset( $settings['enable-sub-title'] ) && $settings['enable-sub-title'] ) {

				$breadcrumbs = array();
				$bstyle = ora_cs_get_option( 'breadcrumb-style', 'default' );
				$separator = '<span class="'.ora_cs_get_option( 'breadcrumb-delimiter', 'fa default' ).'"></span>';

				$cat = get_the_term_list( $post->ID, 'hb_room_type', '', '$$$', '');
                $cats = array_filter(explode('$$$', $cat));
                if (!empty($cats))
                	$breadcrumbs[] = $cats[0];

				$breadcrumbs[] = the_title( '<span class="current">', '</span>', false );
				$bcsettings = isset( $settings['breadcrumb_background'] ) ? $settings['breadcrumb_background'] : array();
				$style = ora_breadcrumb_css( $bcsettings );

				ora_breadcrumb_output ( the_title( '<h1>', '</h1>',false ), $breadcrumbs, $bstyle, $style );
			}
		}
    ?><!-- ** Breadcrumb End ** -->

</div><!-- ** Header Wrapper - End ** -->

<!-- **Main** -->
<div id="main">

    <!-- ** Container ** -->
    <div class="container"><?php
        $page_layout  = array_key_exists( "layout", $settings ) ? $settings['layout'] : "content-full-width";
        $layout = ora_page_layout( $page_layout );
        extract( $layout );

        if ( $show_sidebar ) {
            if ( $show_left_sidebar ) {?>
                <!-- Secondary Left -->
                <section id="secondary-left" class="secondary-sidebar <?php echo esc_attr( $sidebar_class );?>"><?php
                    ora_show_sidebar( 'hb_room', $post->ID, 'left' ); ?></section><!-- Secondary Left End --><?php
            }
        }?>

        <!-- Primary -->
        <section id="primary" class="<?php echo esc_attr( $page_layout );?>">
			<?php
            /**
             * hotel_booking_before_main_content hook
             */
            do_action( 'hotel_booking_before_main_content' );
            ?>

            <?php while ( have_posts() ) : the_post(); ?>

                <?php hb_get_template_part( 'content', 'single-room' ); ?>

            <?php endwhile; ?>

            <?php
            /**
             * hotel_booking_after_main_content hook
             */
            do_action( 'hotel_booking_after_main_content' );
            ?>
        </section><!-- Primary End --><?php

        if ( $show_sidebar ) {
            if ( $show_right_sidebar ) {?>
                <!-- Secondary Right -->
                <section id="secondary-right" class="secondary-sidebar <?php echo esc_attr( $sidebar_class );?>"><?php
                    ora_show_sidebar( 'hb_room', $post->ID, 'right' ); ?></section><!-- Secondary Right End --><?php
            }
        }?>
    </div>
    <!-- ** Container End ** -->
</div><!-- **Main - End ** -->
<?php get_footer(); ?>