<?php
/**
 * The template for displaying trips archive page
 *
 * @package Wp_Travel_Engine
 * @subpackage Wp_Travel_Engine/includes/templates
 * @since 1.0.0
 */
/**
 * Prevent loading this file directly
 */
defined( 'ABSPATH' ) || exit();

get_header();

$global_breadcrumb = cs_get_option( 'show-breadcrumb' );
$header_class	   = cs_get_option( 'breadcrumb-position' ); ?>

<!-- ** Header Wrapper ** -->
<div id="header-wrapper" class="<?php echo esc_attr($header_class); ?>">

	<!-- **Header** -->
	<header id="header">
		<div class="container"><?php
	        /**
	         * ora_header hook.
	         * 
	         * @hooked ora_vc_header_template - 10
	         *
	         */
	        do_action( 'ora_header' ); ?>
	    </div>
	</header><!-- **Header - End ** -->

	<!-- ** Breadcrumb ** -->
    <?php
        if( !empty( $global_breadcrumb ) ) {

        	$bstyle = ora_cs_get_option( 'breadcrumb-style', 'default' );
        	$style = ora_breadcrumb_css();

            $title = '<h1>'.get_the_archive_title().'</h1>';
            $breadcrumbs[] = esc_html__('Trips', 'ora');

            ora_breadcrumb_output ( $title, $breadcrumbs, $bstyle, $style );
        }
    ?><!-- ** Breadcrumb End ** -->
</div><!-- ** Header Wrapper - End ** -->

<!-- **Main** -->
<div id="main">
    <!-- ** Container ** -->
    <div class="container"><?php
    	$page_layout  = cs_get_option( 'trip-archives-page-layout' );
    	$page_layout  = !empty( $page_layout ) ? $page_layout : "content-full-width";

    	$layout = ora_page_layout( $page_layout );
    	extract( $layout );

    	if ( $show_sidebar ) {
    		if ( $show_left_sidebar ) {?>
    		 	<!-- Secondary Left -->
    			<section id="secondary-left" class="secondary-sidebar <?php echo esc_attr( $sidebar_class );?>"><?php
					$enable = cs_get_option( 'show-standard-left-sidebar-for-trip-archives' );
					if( !empty( $enable )):
						if( is_active_sidebar('standard-sidebar-left') ):
							dynamic_sidebar('standard-sidebar-left');
						endif;
					endif;?>
    			</section><!-- Secondary Left End --><?php
    		}
    	}?>

    	<!-- Primary -->
        <section id="primary" class="<?php echo esc_attr( $page_layout );?>">
			<?php
            /**
             * wp_travel_engine_trip_archive_outer_wrapper hook.
             *
             * @hooked wp_travel_engine_trip_archive_outer_wrapper - 10 (main wrapper)
             */ 
            do_action('wp_travel_engine_trip_archive_outer_wrapper');?>
            <?php
            /**
             * wp_travel_engine_trip_archive_loop_start hook.
             *
             * @hooked wp_travel_engine_trip_archive_loop_start - 10 (loop starts)
             */ 
            do_action('wp_travel_engine_trip_archive_loop_start');?>
            <?php
            /**
             * wp_travel_engine_trip_archive_wrap hook.
             *
             * @hooked wp_travel_engine_trip_archive_wrap - 10 (inner wrapper)
             */ 
            do_action('wp_travel_engine_trip_archive_wrap');?>
            <?php
            /**
             * wp_travel_engine_trip_archive_loop_end hook.
             *
             * @hooked wp_travel_engine_trip_archive_loop_end - 10 (loop ends)
             */ 
            do_action('wp_travel_engine_trip_archive_loop_end');?>
            <?php
            /**
             * wp_travel_engine_trip_archive_pagination hook.
             *
             * @hooked wp_travel_engine_trip_archive_pagination - 10 (pagination for archive)
             */ 
            do_action('wp_travel_engine_trip_archive_pagination');?>
            <?php
            /**
             * wp_travel_engine_trip_archive_outer_wrapper_close hook.
             *
             * @hooked wp_travel_engine_trip_archive_outer_wrapper_close - 10 (main wrapper close)
             */ 
            do_action('wp_travel_engine_trip_archive_outer_wrapper_close');?>
        </section><!-- Primary End --><?php

    	if ( $show_sidebar ) {
    		if ( $show_right_sidebar ) {?>
    		 	<!-- Secondary Right -->
    			<section id="secondary-right" class="secondary-sidebar <?php echo esc_attr( $sidebar_class );?>"><?php
					$enable = cs_get_option( 'show-standard-right-sidebar-for-trip-archives' );
					if( !empty( $enable )):
						if( is_active_sidebar('standard-sidebar-right') ):
							dynamic_sidebar('standard-sidebar-right');
						endif;
					endif;?>
    			</section><!-- Secondary Right End --><?php
    		}
    	}?>
    </div>
    <!-- ** Container End ** -->
</div><!-- **Main - End ** -->
<?php get_footer(); ?>