<?php
/**
 * The template for displaying trip reviews (comment).
 *
 * @package Wp_Travel_Engine
 * @subpackage Wp_Travel_Engine/includes
 * @since 1.0.0
 */
/**
 * Prevent loading this file directly
 */
defined( 'ABSPATH' ) || exit();

global $post;
$rating = dt_travel_trip_average_rating( $post->ID );
$rating = number_format($rating, 1);

if ( ! comments_open() ) {
	return;
} ?>

<div id="reviews">

	<div class="dt-sc-title with-before-after-shape alignleft">
    	<h2 class="dt-sc-main-heading"><?php esc_html_e('Ratings', 'ora'); ?></h2>
    </div>

	<?php if ( $count = dt_travel_get_review_count( $post->ID ) ) { ?>
        <div class="te-single-trip-rating-wrapper">
            <div class="te-trip-rating-box">
                <div class="te-trip-average-rating-value"><?php echo esc_html($rating).' / 5'; ?></div>
                <div itemprop="reviewRating" itemscope itemtype="http://schema.org/Rating" class="star-rating"
                     title="<?php echo sprintf( esc_attr__( 'Rated %d out of 5', 'ora' ), $rating ); ?>">
                    <span style="width:<?php echo esc_attr(( $rating / 5 ) * 100); ?>%"></span>
                </div>
                <div class="te-trip-total-rating">(<?php echo esc_html($count).' '.esc_html__('Ratings', 'ora').', <span>'.esc_html__('Avg', 'ora').'</span> '.$rating.' out of 5)'; ?></div>
            </div>
            <div class="te-trip-ratings-breakup"><?php
				$a = dt_travel_trip_individual_rating($post->ID);
				$res = array_count_values($a); ?>
                <ul>
                    <li>
                        <span class="te-trip-ratings-label">5</span>
                        <div class="te-trip-ratings-percentage">
                            <span class="dark-green" style="width:<?php echo ( (array_key_exists('5', $res ) ? $res[5] : 0) / $count ) * 100; ?>%"></span>
                        </div>
                        <span><?php echo array_key_exists('5', $res ) ? $res[5] : 0; ?></span>
                    </li>
                    <li>
                        <span class="te-trip-ratings-label">4</span>
                        <div class="te-trip-ratings-percentage">
                            <span class="green" style="width:<?php echo ( (array_key_exists('4', $res ) ? $res[4] : 0) / $count ) * 100; ?>%"></span>
                        </div>
                        <span><?php echo array_key_exists('4', $res ) ? $res[4] : 0; ?></span>
                    </li>
                    <li>
                        <span class="te-trip-ratings-label">3</span>
                        <div class="te-trip-ratings-percentage">
                            <span class="light-green" style="width:<?php echo ( (array_key_exists('3', $res ) ? $res[3] : 0) / $count ) * 100; ?>%"></span>
                        </div>
                        <span><?php echo array_key_exists('3', $res ) ? $res[3] : 0; ?></span>
                    </li>
                    <li>
                        <span class="te-trip-ratings-label">2</span>
                        <div class="te-trip-ratings-percentage">
                            <span class="yellow" style="width:<?php echo ( (array_key_exists('2', $res ) ? $res[2] : 0) / $count ) * 100; ?>%"></span>
                        </div>
                        <span><?php echo array_key_exists('2', $res ) ? $res[2] : 0; ?></span>
                    </li>
                    <li>
                        <span class="te-trip-ratings-label">1</span>
                        <div class="te-trip-ratings-percentage">
                            <span class="red" style="width:<?php echo ( (array_key_exists('1', $res ) ? $res[1] : 0) / $count ) * 100; ?>%"></span>
                        </div>
                        <span><?php echo array_key_exists('1', $res ) ? $res[1] : 0; ?></span>
                    </li>
                </ul>
            </div>
        </div><?php
	} ?>

    <div id="comments">
        <div class="dt-sc-title with-before-after-shape alignleft">
            <h2 class="dt-sc-main-heading"><?php esc_html_e('Our Reviews', 'ora'); ?></h2>
        </div>

		<?php if ( have_comments() ) { ?>
            <ul class="commentlist">
				<?php wp_list_comments( apply_filters( 'te_trip_review_list_args', array( 'callback' => 'dt_travel_te_comments' ) ) ); ?>
            </ul>

			<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) { ?>
                <nav class="te-pagination">
					<?php paginate_comments_links( apply_filters( 'te_comment_pagination_args', array(
						'prev_text' => '&larr;',
						'next_text' => '&rarr;',
						'type'      => 'list',
					) ) );
					?>
                </nav>
			<?php } ?>

		<?php } else { ?>
            <p class="te-noreviews"><?php esc_html_e( 'There are no reviews yet.', 'ora' ); ?></p>
		<?php } ?>
    </div>

    <div id="review_form_wrapper">
        <div id="review_form">
            <?php
            $commenter    = wp_get_current_commenter();
            $comment_form = array(
                'title_reply'          => have_comments() ? esc_html__( 'Add a review', 'ora' ) : esc_html__( 'Be the first to review', 'ora' ) . ' &ldquo;' . get_the_title() . '&rdquo;',
                'title_reply_to'       => esc_html__( 'Leave a Reply to %s', 'ora' ),
                'comment_notes_before' => '',
                'comment_notes_after'  => '',
                'fields'               => array(
                    'author' => '<p class="comment-form-author">' . '<label for="author">' . esc_html__( 'Name', 'ora' ) . ' <span class="required">*</span></label> ' .
                                '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" aria-required="true" /></p></div>',
                    'email'  => '<p class="comment-form-email"><label for="email">' . esc_html__( 'Email', 'ora' ) . ' <span class="required">*</span></label> ' .
                                '<input id="email" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" aria-required="true" /></p></div>',
                ),
                'label_submit'         => esc_html__( 'Submit', 'ora' ),
                'logged_in_as'         => '',
                'comment_field'        => ''
            );

            $comment_form['fields']['author'] .= '<div class="column dt-sc-one-half"><p class="comment-form-author-role">' . '<label for="author-role">' . esc_html__( 'Role', 'ora' ) . '</label> ' . '<input id="author-role" name="author-role" type="text" size="30" aria-required="true" /></p>';

			$comment_form['comment_field'] = '<p class="comment-form-rating"><label for="rating">' . esc_html__( 'Your Rating', 'ora' ) . '</label></p><div class="hb-rating-input"></div>';

            $comment_form['comment_field'] .= '<p class="comment-form-comment"><label for="comment">' . esc_html__( 'Your Review', 'ora' ) . '</label><textarea id="comment" name="comment" cols="45" rows="8" aria-required="true"></textarea></p>';

            $comment_form['comment_field'] .= '<div class="column dt-sc-one-half first"><p class="comment-form-title"><label for="comment-title">' . esc_html__( 'Review Title', 'ora' ) . ' <span class="required">*</span></label><input id="comment-title" name="comment-title" type="text" size="30" aria-required="true" /></p>';

            comment_form( apply_filters( 'te_trip_review_comment_form_args', $comment_form ) );
            ?>
        </div>
    </div>

    <div class="clear"></div>
</div>