<?php
/**
* The template for displaying all single trips
*
* @package Wp_Travel_Engine
* @subpackage Wp_Travel_Engine/includes
* @since 1.0.0
*/
/**
 * Prevent loading this file directly
 */
defined( 'ABSPATH' ) || exit();

get_header();
global $post;

$global_breadcrumb = cs_get_option( 'show-breadcrumb' );

$settings = get_post_meta($post->ID,'_custom_settings',TRUE);
$settings = is_array( $settings ) ?  array_filter( $settings )  : array();

$header_class = '';
if( !empty( $global_breadcrumb ) ) {
	if( isset( $settings['enable-sub-title'] ) && $settings['enable-sub-title'] ) {
		$header_class = isset( $settings['breadcrumb_position'] ) ? $settings['breadcrumb_position'] : '';
	}
}?>
<!-- ** Header Wrapper ** -->
<div id="header-wrapper" class="<?php echo esc_attr($header_class); ?>">

    <!-- **Header** -->
    <header id="header">

        <div class="container"><?php
            /**
             * ora_header hook.
             * 
             * @hooked ora_vc_header_template - 10
             *
             */
            do_action( 'ora_header' ); ?>
        </div>
    </header><!-- **Header - End ** -->

    <!-- ** Breadcrumb ** -->
    <?php
		# Global Breadcrumb
		if( !empty( $global_breadcrumb ) ) {

			if(empty($settings)) { $settings['enable-sub-title'] = true; }

			if( isset( $settings['enable-sub-title'] ) && $settings['enable-sub-title'] ) {

				$breadcrumbs = array();
				$bstyle = ora_cs_get_option( 'breadcrumb-style', 'default' );
				$separator = '<span class="'.ora_cs_get_option( 'breadcrumb-delimiter', 'fa default' ).'"></span>';

				$cat = get_the_term_list( $post->ID, 'destination', '', '$$$', '');
                $cats = array_filter(explode('$$$', $cat));
                if (!empty($cats))
                	$breadcrumbs[] = $cats[0];

				$breadcrumbs[] = the_title( '<span class="current">', '</span>', false );
				$bcsettings = isset( $settings['breadcrumb_background'] ) ? $settings['breadcrumb_background'] : array();
				$style = ora_breadcrumb_css( $bcsettings );

				ora_breadcrumb_output ( the_title( '<h1>', '</h1>',false ), $breadcrumbs, $bstyle, $style );
			}
		}
    ?><!-- ** Breadcrumb End ** -->

</div><!-- ** Header Wrapper - End ** -->

<!-- **Main** -->
<div id="main">

    <!-- ** Container ** -->
    <div class="container"><?php
        $page_layout  = array_key_exists( "layout", $settings ) ? $settings['layout'] : "content-full-width";
        $layout = ora_page_layout( $page_layout );
        extract( $layout );

        if ( $show_sidebar ) {
            if ( $show_left_sidebar ) {?>
                <!-- Secondary Left -->
                <section id="secondary-left" class="secondary-sidebar <?php echo esc_attr( $sidebar_class );?>"><?php
					if( array_key_exists( 'show-travel-engine-sidebar', $settings ) ) {

						$wtstyle = cs_get_option( 'wtitle-style' );
						if(!empty($wtstyle)):
							echo "<div class='{$wtstyle}'>";
						endif;

							do_action( 'wp_travel_engine_trip_price' );
							do_action( 'wp_travel_engine_trip_facts' );
							do_action( 'wp_travel_engine_trip_gallery' );
							do_action( 'wp_travel_engine_trip_map' );
							do_action( 'wp_travel_engine_wte_sidebar' );

						if(!empty($wtstyle)):
							echo "</div>";
						endif;
					}
					#Standard Left Sidebar...
                    ora_show_sidebar( 'trip', $post->ID, 'left' ); ?></section><!-- Secondary Left End --><?php
            }
        }?>

        <!-- Primary -->
        <section id="primary" class="<?php echo esc_attr( $page_layout );?>">
            <div class="post-thumbnail"><?php
				if (has_action('wp_travel_engine_feat_img_trip_galleries')) {
					do_action('wp_travel_engine_feat_img_trip_galleries');
				}
				else {
					$trip_feat_img_size = apply_filters('wp_travel_engine_single_trip_feat_img_size', 'trip-single-size');
					$feat_image_url = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID) , $trip_feat_img_size); ?>

					<img itemprop="image" src="<?php echo esc_url($feat_image_url[0]); ?>" alt="<?php the_title_attribute(); ?>"><?php
				} ?>
            </div>
			<div class="dt-sc-trip-entry-details">
                <div class="title-wrapper">
                    <h2 class="entry-title" itemprop="name"><?php the_title(); ?></h2>
                    <span class="title-meta"><i class="zmdi zmdi-pin"></i><?php echo get_the_term_list( $post->ID, 'destination', '', ', ', '' ); ?></span>
                </div>
                
                <div class="price-wrapper"><?php
                    #Price...
                    $wp_travel_engine_meta = get_post_meta( $post->ID, 'wp_travel_engine_setting', true );
                    $wp_travel_engine_meta = is_array ( $wp_travel_engine_meta ) ? $wp_travel_engine_meta : array ();
        
                    $wp_travel_engine_setting = get_option('wp_travel_engine_settings', true);
        
                    $code = 'USD';
                    if( isset( $wp_travel_engine_setting['currency_code'] ) && $wp_travel_engine_setting['currency_code'] != '' ) {
                        $code = esc_attr( $wp_travel_engine_setting['currency_code'] );
                    }
                    $obj = new Wp_Travel_Engine_Functions();
                    $currency = $obj->wp_travel_engine_currencies_symbol( $code );
                    $cost = isset( $wp_travel_engine_meta['trip_price'] ) ? $wp_travel_engine_meta['trip_price']: '';
        
                    $prev_cost = isset( $wp_travel_engine_meta['trip_prev_price'] ) ? $wp_travel_engine_meta['trip_prev_price']: '';
        
                    $code = 'USD';
                    if( isset( $wp_travel_engine_setting['currency_code'] ) && $wp_travel_engine_setting['currency_code'] != '' ) {
                        $code = $wp_travel_engine_setting['currency_code'];
                    }
                    $obj = new Wp_Travel_Engine_Functions();
                    $currency = $obj->wp_travel_engine_currencies_symbol( $code );
                    $prev_cost = isset( $wp_travel_engine_meta['trip_prev_price'] ) ? $wp_travel_engine_meta['trip_prev_price']: '';
                    if( $cost != '' && isset( $wp_travel_engine_meta['sale'] ) ) {
                        $obj = new Wp_Travel_Engine_Functions();
                        echo '<span class="price-holder" itemprop="priceRange">'.esc_html__('from', 'ora').' <sup>'.esc_attr($currency).'</sup><span class="amount">'.esc_attr( $obj->wp_travel_engine_price_format($cost) ).'</span><span> / '.esc_html__('person', 'ora').'</span></span>';
                    }
                    else {
                        if( $prev_cost != '' ) {
                            $obj = new Wp_Travel_Engine_Functions();
                            echo '<span class="price-holder" itemprop="priceRange">'.esc_html__('from', 'ora').' <sup>'.esc_attr($currency).'</sup><span class="amount">'.esc_attr( $obj->wp_travel_engine_price_format($prev_cost) ).'</span><span> / '.esc_html__('person', 'ora').'</span></span>';
                        }
                    }
        
                    #Reviews...
                    $rating = dt_travel_trip_average_rating( $post->ID );
                    if ( $rating ) { ?>
                        <p class="rating"><span class="zmdi zmdi-star-circle"></span><?php echo esc_html($rating).' / 5'; ?></p><?php
                    } ?>
                </div>
    
                <div class="column dt-sc-one-column"><?php
                    //Trip Meta...
                    $trip_meta = get_post_meta( $post->ID, '_custom_settings', true );
                    $trip_meta = is_array ( $trip_meta ) ? $trip_meta : array ();

                    if( array_key_exists('email_address', $trip_meta) && $trip_meta['email_address'] != '' ){
                        echo '<div class="email-wrapper">';
                            echo '<span class="trip-email"><i class="zmdi zmdi-email"></i>'.esc_html__('Email:', 'ora').'<a href="mailto:'.$trip_meta['email_address'].'" target="_blank">'.$trip_meta['email_address'].'</a></span>';
                        echo '</div>';
                    }
                    if( array_key_exists('phone_no', $trip_meta) && $trip_meta['phone_no'] != '' ){
                        echo '<div class="phone-wrapper">';
                            echo '<span class="trip-phone"><i class="zmdi zmdi-phone"></i><a href="tel:'.$trip_meta['phone_no'].'" target="_blank">'.$trip_meta['phone_no'].'</a></span>';
                        echo '</div>';
                    } ?>
                    <div class="likes-wrapper"><?php
                        /**
                         * travel_engine_single_trip_likes hook
                         */
                        do_action( 'travel_engine_single_trip_likes' );
            
                        /**
                         * travel_engine_single_trip_social hook
                         */
                        do_action( 'travel_engine_single_trip_social' ); ?>
                    </div>
                </div>
            </div>

            <div class="trip-post-content"><?php
				if( have_posts() ) {
                	while( have_posts() ) {
                    	the_post();

						// Getting tabs and content...
						dt_travel_get_template( 'wp-travel-engine/single-trip/trip-tabs.php' );
						the_content();
					}
				} ?>
            </div>

            <?php
			$wp_travel_engine_settings = get_option( 'wp_travel_engine_settings',true );
	        if( !isset( $wp_travel_engine_settings['enquiry'] ) ) {
	            do_action ( 'wp_travel_engine_enquiry_form' );
			} ?>

			<div class="te_single_trip_reviews">
			    <?php do_action( 'travel_engine_single_trip_after_tabs_content_te_trip_reviews' ); ?>
            </div>

            <div class="te_single_related_posts"><?php
				do_action ( 'wp_travel_engine_before_related_posts' );
				do_action ( 'wp_travel_engine_related_posts' );
				do_action ( 'wp_travel_engine_after_related_posts' ); ?></div>

        </section><!-- Primary End --><?php

        if ( $show_sidebar ) {
            if ( $show_right_sidebar ) {?>
                <!-- Secondary Right -->
                <section id="secondary-right" class="secondary-sidebar <?php echo esc_attr( $sidebar_class );?>"><?php
					if( array_key_exists( 'show-travel-engine-sidebar', $settings ) ) {

						$wtstyle = cs_get_option( 'wtitle-style' );
						if(!empty($wtstyle)):
							echo "<div class='{$wtstyle}'>";
						endif;

							do_action( 'wp_travel_engine_trip_price' );
							do_action( 'wp_travel_engine_trip_facts' );
							do_action( 'wp_travel_engine_trip_gallery' );
							do_action( 'wp_travel_engine_trip_map' );
							do_action( 'wp_travel_engine_wte_sidebar' );

						if(!empty($wtstyle)):
							echo "</div>";
						endif;
					}
					// Standard Right Sidebar...
                    ora_show_sidebar( 'trip', $post->ID, 'right' ); ?></section><!-- Secondary Right End --><?php
            }
        }?>
    </div>
    <!-- ** Container End ** -->
</div><!-- **Main - End ** -->
<?php get_footer(); ?>