<?php
/**
 * The template for displaying trips according to trip_types .
 *
 * @package Wp_Travel_Engine
 * @subpackage Wp_Travel_Engine/includes/templates
 * @since 1.0.0
 */

get_header();

$settings = get_post_meta($post->ID,'_tpl_default_settings',TRUE);
$settings = is_array( $settings ) ?  array_filter( $settings )  : array();

$global_breadcrumb = cs_get_option( 'show-breadcrumb' );

$header_class = '';
if( !isset( $settings['enable-sub-title'] ) || !$settings['enable-sub-title']  ) {
	if( isset( $settings['show_slider'] ) && $settings['show_slider'] ) {
		if( isset( $settings['slider_type'] ) ) {
			$header_class =  $settings['slider_position'];
		}
	}
}

if( !empty( $global_breadcrumb ) ) {
	if( isset( $settings['enable-sub-title'] ) && $settings['enable-sub-title'] ) {
		$header_class = isset( $settings['breadcrumb_position'] ) ? $settings['breadcrumb_position'] : '';
	}
}?>
<!-- ** Header Wrapper ** -->
<div id="header-wrapper" class="<?php echo esc_attr($header_class); ?>">              
    
    <!-- **Header** -->
    <header id="header">

        <div class="container"><?php
            /**
             * ora_header hook.
             * 
             * @hooked ora_vc_header_template - 10
             *
             */
            do_action( 'ora_header' ); ?>
        </div>
    </header><!-- **Header - End ** -->

    <!-- ** Slider ** -->
    <?php
        if( !isset( $settings['enable-sub-title'] ) || !$settings['enable-sub-title'] ) {
            if( isset( $settings['show_slider'] ) && $settings['show_slider'] ) {
                if( isset( $settings['slider_type'] ) ) {
                    if( $settings['slider_type'] == 'layerslider' && !empty( $settings['layerslider_id'] ) ) {
                        echo '<div id="slider">';
                        echo '  <div id="dt-sc-layer-slider" class="dt-sc-main-slider">';
                        echo    do_shortcode('[layerslider id="'.$settings['layerslider_id'].'"/]');
                        echo '  </div>';
                        echo '</div>';
					} elseif( $settings['slider_type'] == 'revolutionslider' && !empty( $settings['revolutionslider_id'] ) ) {
                        echo '<div id="slider">';
                        echo '  <div id="dt-sc-rev-slider" class="dt-sc-main-slider">';
                        echo    do_shortcode('[rev_slider '.$settings['revolutionslider_id'].'/]');
                        echo '  </div>';
                        echo '</div>';
					} elseif( $settings['slider_type'] == 'customslider' && !empty( $settings['customslider_sc'] ) ) {
                        echo '<div id="slider">';
                        echo '  <div id="dt-sc-custom-slider" class="dt-sc-main-slider">';
                        echo    do_shortcode( $settings['customslider_sc'] );
                        echo '  </div>';
                        echo '</div>';
					}
                }
            }
        }
    ?><!-- ** Slider End ** -->

    <!-- ** Breadcrumb ** -->
    <?php 
        # Global Breadcrumb
        if( !empty( $global_breadcrumb ) ) {

			if(empty($settings)) { $settings['enable-sub-title'] = true; }

            if( isset( $settings['enable-sub-title'] ) && $settings['enable-sub-title'] ) {
                $breadcrumbs = array();
                $bstyle = ora_cs_get_option( 'breadcrumb-style', 'default' );

                if( $post->post_parent ) {
                    $parent_id  = $post->post_parent;
                    $parents = array();

                    while( $parent_id ) {
                        $page = get_page( $parent_id );
                        $parents[] = '<a href="' . get_permalink( $page->ID ) . '">' . get_the_title( $page->ID ) . '</a>';
                        $parent_id  = $page->post_parent;
                    }

                    $parents = array_reverse( $parents );
                    $breadcrumbs = array_merge_recursive($breadcrumbs, $parents);
                }

                $breadcrumbs[] = the_title( '<span class="current">', '</span>', false );
				$bcsettings = isset( $settings['breadcrumb_background'] ) ? $settings['breadcrumb_background'] : array();
                $style = ora_breadcrumb_css( $bcsettings );

                ora_breadcrumb_output ( the_title( '<h1>', '</h1>',false ), $breadcrumbs, $bstyle, $style );
            }
        }
    ?><!-- ** Breadcrumb End ** -->
</div><!-- ** Header Wrapper - End ** -->

<!-- **Main** -->
<div id="main">

    <!-- ** Container ** -->
    <div class="container"><?php
        $page_layout  = array_key_exists( "layout", $settings ) ? $settings['layout'] : "content-full-width";
        $layout = ora_page_layout( $page_layout );
        extract( $layout );

        if ( $show_sidebar ) {
            if ( $show_left_sidebar ) {
                $sticky_class = ( array_key_exists('enable-sticky-sidebar', $settings) && $settings['enable-sticky-sidebar'] == 'true' ) ? ' sidebar-as-sticky' : '';?>
                
                <!-- Secondary Left -->
                <section id="secondary-left" class="secondary-sidebar <?php echo esc_attr( $sidebar_class.$sticky_class );?>"><?php
                    ora_show_sidebar( 'page', $post->ID, 'left' );
                ?></section><!-- Secondary Left End --><?php
            }
        }?>

        <!-- Primary -->
        <section id="primary" class="<?php echo esc_attr( $page_layout );?>">
            <div id="wte-crumbs"><?php
                $obj = new Wp_Travel_Engine_Functions();
                do_action('wp_travel_engine_breadcrumb_holder'); ?>
            </div>
            <div id="wp-travel-trip-wrapper" class="trip-content-area" itemscope itemtype="http://schema.org/LocalBusiness">
                <div class="wp-travel-inner-wrapper">
                    <div class="wp-travel-engine-archive-outer-wrap">
                        <?php
                        $termID = get_queried_object()->term_id; // Parent A ID
                        $taxonomyName = 'trip_types';
                        $order = apply_filters('wpte_trip_types_terms_order','ASC');
                        $orderby = apply_filters('wpte_trip_types_terms_order_by','date');
                        $termchildren = get_terms($taxonomyName, array('orderby' => $orderby, 'order' => $order));
                        // $termchildren = get_terms( $taxonomyName );
                        if($termchildren) {
                            ?>
                            <div class="page-header">
                                <h2 class="page-title" data-id="<?php echo esc_attr($taxonomyName);?>"><?php the_title(); ?></h2>
                                <div class="page-feat-image">
                                    <?php
                                    $image_id = get_post_thumbnail_id( $post->ID );
                                    $activities_banner_size = apply_filters('wp_travel_engine_template_banner_size', 'full');
                                    echo wp_get_attachment_image ( $image_id, $activities_banner_size );
                                    ?> 
                                  </div>
                                <div class="page-content">
                                    <p>
                                        <?php global $post; 
                                        $post = get_post($post->ID); 
                                        $content = apply_filters('the_content', $post->post_content); 
                                        echo "{$content}";?>
                                    </p>
                                </div>
                            </div>
                            <div class="trip_types-holder">
                                <?php 
                                foreach ($termchildren as $child) {
                                    $term = get_term_by( 'id', $child->term_id, 'trip_types' ); 
                                    $term_link = get_term_link( $term );
                                    $child_term_description = term_description( $term, 'trip_types' );
                                    ?> 
                                        <div class="item">
                                            <address itemprop="address" style="display: none;"><?php the_title(); ?></address>
                                            <div itemprop="priceRange" style="display: none;"><?php echo esc_html($obj->trip_price($post->ID)); ?></div>
                                            <div class="img-holder">
                                                    <?php 
                                                    $image_id = get_term_meta ( $child->term_id, 'category-image-id', true );
                                                    if(isset($image_id) && $image_id!='' )
                                                    {
                                                        $activities_thumb_size = apply_filters('wp_travel_engine_activities_img_size', 'activities-thumb-size');
                                                        echo wp_get_attachment_image ( $image_id, $activities_thumb_size );
                                                    }
                                                    else{
                                                        echo '<img itemprop="image" src="'.esc_url(  WP_TRAVEL_ENGINE_IMG_URL . '/public/css/images/activity-trip-type.jpg' ).'">';
                                                    }
                                                    ?>
                                                <div class="title-holder"><?php echo esc_attr( $term->name );?></div>
                                                <div class="text-holder">
                                                    <div class="text">
                                                    <h3 class="title" itemprop="name"><?php echo esc_attr( $term->name );?></h3>
                                                    <p><?php echo term_description( $child->term_id, 'trip_types' ); ?></p>
                                                    </div>
                                                    <a class="btn-more" href="<?php echo esc_url( $term_link );?>">&rarr;</a>
                                                </div>
                                            </div>
                                        </div>
                                    <?php
                                }
                                ?>
                            </div>
                        <?php     
                        }
                        else{
                            ?>
                            <div class="page-header">
                                <h2 class="page-title" data-id="<?php echo esc_attr($taxonomyName);?>"><?php the_title(); ?></h2>
                                <div class="page-feat-image">
                                  <?php
                                  the_post_thumbnail();
                                  ?> 
                                </div>
                                <div class="page-content">
                                  <?php
                                  global $post; 
                                  $post = get_post($post->ID); 
                                  $content = apply_filters('the_content', $post->post_content); 
                                  echo "{$content}"; ?>
                                </div>
                            </div>
                            <?php
                          } 
                        ?>
                    </div>
                </div>
            </div>
        </section><!-- Primary End --><?php

        if ( $show_sidebar ) {
            if ( $show_right_sidebar ) {
                $sticky_class = ( array_key_exists('enable-sticky-sidebar', $settings) && $settings['enable-sticky-sidebar'] == 'true' ) ? ' sidebar-as-sticky' : '';?>

                <!-- Secondary Right -->
                <section id="secondary-right" class="secondary-sidebar <?php echo esc_attr( $sidebar_class.$sticky_class );?>"><?php
                    ora_show_sidebar( 'page', $post->ID, 'right' );
                ?></section><!-- Secondary Right End --><?php
            }
        }?>
    </div>
    <!-- ** Container End ** -->

</div><!-- **Main - End ** -->
<?php get_footer(); ?>